<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro">
<context>
    <name>MircastShowWidget</name>
    <message>
        <source>Projecting... 
Please do not exit the Movie app during the process.</source>
        <translation>Proiectarea... 
Vă rugăm să nu părăsiți aplicația Movie în timpul procesului.</translation>
    </message>
    <message>
        <source>Display device</source>
        <translation>Dispozitiv de afișare</translation>
    </message>
    <message>
        <source>Exit Miracast</source>
        <translation>Ieșire din Miracast</translation>
    </message>
</context>
<context>
    <name>MircastWidget</name>
    <message>
        <source>Project to</source>
        <translation>Proiectați către</translation>
    </message>
    <message>
        <source>Searching for devices...</source>
        <translation>Căutare dispozitive...</translation>
    </message>
    <message>
        <source>No Miracast display devices were found. Please connect the device and your computer to the same WLAN network.</source>
        <translation>Nu s-au găsit dispozitive Miracast de afișare. Vă rugăm să conectați dispozitivul și computerul la aceeași rețea WLAN.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Invalid folder</source>
        <translation>Dosar invalid</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Deschide dosar</translation>
    </message>
    <message>
        <source>Network disconnected</source>
        <translation>Rețea dezconectată</translation>
    </message>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Nu aveți permisiunea necesară pentru a efectua operațiuni în acest dosar.</translation>
    </message>
    <message>
        <source>Auto add similar files to play</source>
        <translation>Adaugă automat fișiere similare în lista de redare</translation>
    </message>
    <message>
        <source>Clear playlist when exit</source>
        <translation>Golire lista de redare la ieșire</translation>
    </message>
    <message>
        <source>Show video preview on mouseover</source>
        <translation>Arată o previzualizare a video-ului când se trece cu mouse-ul peste</translation>
    </message>
    <message>
        <source>Open a new player for each file played</source>
        <translation>Deschide o fereastră nouă pentru fiecare fișier redat</translation>
    </message>
    <message>
        <source>Pause when minimized</source>
        <translation>Pauză la minimizare</translation>
    </message>
    <message>
        <source>Remember playback position</source>
        <translation>Memorare poziție redare</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Cale fișier</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Simplu</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Redare</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captură  ecran</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Scurtături</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Fişier</translation>
    </message>
    <message>
        <source>Frame/Sound</source>
        <translation>Cadru/Sunet</translation>
    </message>
    <message>
        <source>Playback</source>
        <translation>Redare</translation>
    </message>
    <message>
        <source>Subtitle</source>
        <translation>Subtitrări</translation>
    </message>
    <message>
        <source>Font Style</source>
        <translation>Stil font</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Restaurare setări implicite</translation>
    </message>
    <message>
        <source>Open file</source>
        <translation>Deschide fișierul</translation>
    </message>
    <message>
        <source>Open next</source>
        <translation>Deschide următor</translation>
    </message>
    <message>
        <source>Open previous</source>
        <translation>Deschide precedent</translation>
    </message>
    <message>
        <source>Mini mode</source>
        <translation>Minimalizare fereastră</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Mute</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Cadrul următor</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Cadrul trecut</translation>
    </message>
    <message>
        <source>Volume down</source>
        <translation>Scade volumul</translation>
    </message>
    <message>
        <source>Volume up</source>
        <translation>Crește volumul</translation>
    </message>
    <message>
        <source>Speed up</source>
        <translation>Mărește viteza de redare</translation>
    </message>
    <message>
        <source>Speed down</source>
        <translation>Scade viteza de redare</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Redare ecran complet</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>Pauză/Redare</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation>Lista de redare</translation>
    </message>
    <message>
        <source>Reset speed</source>
        <translation>Resetează viteza de redare</translation>
    </message>
    <message>
        <source>Rewind</source>
        <translation>Înapoi</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Înainte</translation>
    </message>
    <message>
        <source>Film screenshot</source>
        <translation>Captură ecran video</translation>
    </message>
    <message>
        <source>0.5s backward</source>
        <translation>0.5s înapoi</translation>
    </message>
    <message>
        <source>0.5s forward</source>
        <translation>0.5s înainte</translation>
    </message>
    <message>
        <source>Font</source>
        <translation>Fontul</translation>
    </message>
    <message>
        <source>Exit fullscreen/mini mode</source>
        <translation>Ieșire din modul fullscreen/mini</translation>
    </message>
    <message>
        <source>Movie</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Setări</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajutor</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Afișează scurtături</translation>
    </message>
    <message>
        <source>Delete from playlist</source>
        <translation>Șterge din playlist</translation>
    </message>
    <message>
        <source>Film info</source>
        <translation>Informație video</translation>
    </message>
    <message>
        <source>Burst shooting</source>
        <translation>Fotografie rapidă</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Dimensiune</translation>
    </message>
    <message>
        <source>Movie is a full-featured video player, supporting playing local and streaming media in multiple video formats.</source>
        <translation>Movie este un player video complet, care susține jocul mediilor locale și streaming în mai multe formate video.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Show thumbnails in progress bar</source>
        <translation>Arată miniature în bara de progres</translation>
    </message>
    <message>
        <source>Default play mode</source>
        <translation>Mod joc implicit</translation>
    </message>
    <message>
        <source>Decoding</source>
        <translation>Decodare</translation>
    </message>
    <message>
        <source>Auto select (Recommended)</source>
        <translation>Alegere automată (Recomandat)</translation>
    </message>
    <message>
        <source>Hardware decoding</source>
        <translation>Decodare hardware</translation>
    </message>
    <message>
        <source>Software decoding</source>
        <translation>Decodare software</translation>
    </message>
    <message>
        <source>Customize</source>
        <translation>Personalizați</translation>
    </message>
    <message>
        <source>Decode mode</source>
        <translation>Mod decodare</translation>
    </message>
    <message>
        <source>Video out</source>
        <translation>Video out</translation>
    </message>
    <message>
        <source>The custom decoding method needs to be restarted before it can take effect,
and whether to restart it?</source>
        <translation>Metoda de decodare personalizată trebuie reluată înainte de a putea avea efect,
și dacă să o reluați?</translation>
    </message>
    <message>
        <source>Rendering engine</source>
        <translation>Motor de renderizare</translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Anulare</translation>
    </message>
    <message>
        <source>Please enter the URL:</source>
        <translation>Introduceți adresă URL</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>dmr::ActionFactory</name>
    <message>
        <source>Settings</source>
        <translation>Setări</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Redare ecran complet</translation>
    </message>
    <message>
        <source>Always on Top</source>
        <translation>Mereu deasupra programelor</translation>
    </message>
    <message>
        <source>Empty playlist</source>
        <translation>Goți playlist</translation>
    </message>
    <message>
        <source>Film info</source>
        <translation>Informație video</translation>
    </message>
    <message>
        <source>Open file</source>
        <translation>Deschide fișierul</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Deschide dosar</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation>Deschide URL</translation>
    </message>
    <message>
        <source>Open CD/DVD</source>
        <translation>Deschide CD/DVD</translation>
    </message>
    <message>
        <source>Mini Mode</source>
        <translation>Mod Mini</translation>
    </message>
    <message>
        <source>Play Mode</source>
        <translation>Mod redare</translation>
    </message>
    <message>
        <source>Order Play</source>
        <translation>Redare în ordine</translation>
    </message>
    <message>
        <source>Shuffle Play</source>
        <translation>Redare aleatorie</translation>
    </message>
    <message>
        <source>Single Play</source>
        <translation>Redă un singur fisier</translation>
    </message>
    <message>
        <source>Single Loop</source>
        <translation>Redă video-ul fără pauză</translation>
    </message>
    <message>
        <source>List Loop</source>
        <translation>Redă lista fără pauză</translation>
    </message>
    <message>
        <source>Frame</source>
        <translation>Cadru</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Implicit</translation>
    </message>
    <message>
        <source>Clockwise</source>
        <translation>Rotire la dreapta</translation>
    </message>
    <message>
        <source>Counterclockwise</source>
        <translation>Rotire la stânga</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Sunet</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <source>Left channel</source>
        <translation>Canal audio stanga</translation>
    </message>
    <message>
        <source>Right channel</source>
        <translation>Canal audio dreapta</translation>
    </message>
    <message>
        <source>Track</source>
        <translation>Piesa</translation>
    </message>
    <message>
        <source>Subtitle</source>
        <translation>Subtitrări</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Încarcare</translation>
    </message>
    <message>
        <source>Online Search</source>
        <translation>Căutare online</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Selectare</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Ascundere</translation>
    </message>
    <message>
        <source>Encodings</source>
        <translation>Compresie</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captură  ecran</translation>
    </message>
    <message>
        <source>Film Screenshot</source>
        <translation>Captură ecran video</translation>
    </message>
    <message>
        <source>Burst Shooting</source>
        <translation>Captură ecran rafală</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation>Lista de redare</translation>
    </message>
    <message>
        <source>Film Info</source>
        <translation>Informație video</translation>
    </message>
    <message>
        <source>Delete from playlist</source>
        <translation>Șterge din playlist</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Deschide în managerul de fișiere</translation>
    </message>
    <message>
        <source>Next Frame</source>
        <translation>Fereastră următoare</translation>
    </message>
    <message>
        <source>Previous Frame</source>
        <translation>Fereastră anterioară</translation>
    </message>
    <message>
        <source>Open screenshot folder</source>
        <translation>Deschideți dosarul de ecran</translation>
    </message>
    <message>
        <source>Playback Speed</source>
        <translation>Viteză de redare</translation>
    </message>
    <message>
        <source>0.5x</source>
        <translation>0.5x</translation>
    </message>
    <message>
        <source>1.0x</source>
        <translation>1.0x</translation>
    </message>
    <message>
        <source>1.2x</source>
        <translation>1.2x</translation>
    </message>
    <message>
        <source>1.5x</source>
        <translation>1.5x</translation>
    </message>
    <message>
        <source>2.0x</source>
        <translation>2.0x</translation>
    </message>
</context>
<context>
    <name>dmr::BurstScreenshotsDialog</name>
    <message>
        <source>Duration: %1</source>
        <translation>Durată: %1</translation>
    </message>
    <message>
        <source>Resolution: %1</source>
        <translation>Rezoluție: %1</translation>
    </message>
    <message>
        <source>Size: %1</source>
        <translation>Mărime: %1</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvare</translation>
    </message>
</context>
<context>
    <name>dmr::MainWindow</name>
    <message>
        <source>Load successfully</source>
        <translation>Încărcare efectuată cu succes</translation>
    </message>
    <message>
        <source>Load failed</source>
        <translation>Încărcare eșuată</translation>
    </message>
    <message>
        <source>Buffering...</source>
        <translation>Buferizare...</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Deschide dosar</translation>
    </message>
    <message>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <source>Left channel</source>
        <translation>Canal audio stanga</translation>
    </message>
    <message>
        <source>Right channel</source>
        <translation>Canal audio dreapta</translation>
    </message>
    <message>
        <source>Parse failed</source>
        <translation>Eșec analiză</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Mute</translation>
    </message>
    <message>
        <source>Volume: %1%</source>
        <translation>Volum: %1%</translation>
    </message>
    <message>
        <source>Track: %1</source>
        <translation>Track: %1</translation>
    </message>
    <message>
        <source>Subtitle %1: %2s</source>
        <translation>Subtitrare %1 %2s</translation>
    </message>
    <message>
        <source>delayed</source>
        <translation>întârziere</translation>
    </message>
    <message>
        <source>advanced</source>
        <translation>avansare</translation>
    </message>
    <message>
        <source>Speed: %1x</source>
        <translation>Viteză: %1x</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Aspect</translation>
    </message>
    <message>
        <source>Saved to</source>
        <translation>Salvare la</translation>
    </message>
    <message>
        <source>The screenshot is saved</source>
        <translation>Salvare captura de ecran efectuată</translation>
    </message>
    <message>
        <source>Failed to save the screenshot</source>
        <translation>Eșuat salvare captură de ecran</translation>
    </message>
    <message>
        <source>Invalid file: %1</source>
        <translation>Fișier invalid: %1</translation>
    </message>
    <message>
        <source>No matching online subtitles</source>
        <translation>Nu există subtitrări online corespunzătoare</translation>
    </message>
    <message>
        <source>Cannot open file or stream</source>
        <translation>Nu se poate deschide fișierul sau fluxul</translation>
    </message>
    <message>
        <source>Invalid file</source>
        <translation>Fișier nevalabil</translation>
    </message>
    <message>
        <source>No video file found</source>
        <translation>Nu s-a găsit un fișier video</translation>
    </message>
    <message>
        <source>Film screenshot</source>
        <translation>Captură ecran video</translation>
    </message>
    <message>
        <source>Taking the screenshots, please wait...</source>
        <translation>Se ia ecranele de captură, vă rugăm așteptați...</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Please insert a CD/DVD</source>
        <translation>Vă rugăm să introduceți un CD/DVD</translation>
    </message>
    <message>
        <source>Reading DVD files...</source>
        <translation>Se citesc fișierele DVD...</translation>
    </message>
    <message>
        <source>4K video may be stuck</source>
        <translation>Video-ul 4K poate fi blocat</translation>
    </message>
    <message>
        <source>Please load the video first</source>
        <translation>Vă rugăm să încărcați mai întâi videoul</translation>
    </message>
    <message>
        <source>Order play</source>
        <translation>Jocă în ordine</translation>
    </message>
    <message>
        <source>Shuffle play</source>
        <translation>Jocă în mod aleator</translation>
    </message>
    <message>
        <source>Single play</source>
        <translation>Jocă în mod unic</translation>
    </message>
    <message>
        <source>Single loop</source>
        <translation>Bucătă unică</translation>
    </message>
    <message>
        <source>List loop</source>
        <translation>Bucătă listă</translation>
    </message>
    <message>
        <source>The CD/DVD has been ejected</source>
        <translation>CD-ul/DVD-ul a fost ejectat</translation>
    </message>
    <message>
        <source>Please exit smart dock</source>
        <translation>Vă rugăm să ieșiți din smart dock</translation>
    </message>
    <message>
        <source>Cannot play the disc</source>
        <translation>Nu se poate juca discul</translation>
    </message>
    <message>
        <source>Unable to adjust the subtitle</source>
        <translation>Nu se poate ajusta subtitrărea</translation>
    </message>
    <message>
        <source>The action is not supported in this video</source>
        <translation>Această acțiune nu este suportată în acest videoclip</translation>
    </message>
    <message>
        <source>All (*)</source>
        <translation>Toate (*</translation>
    </message>
    <message>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <comment>All (*)</comment>
        <translation type="unfinished">Subtitrare (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Conexiunea a eșuat</translation>
    </message>
    <message>
        <source>Miracast disconnected</source>
        <translation>Miracast a fost dezconectat</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Anulare</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>Restart</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfo</name>
    <message>
        <source>%1G</source>
        <translation type="vanished">%1G</translation>
    </message>
    <message>
        <source>%1M</source>
        <translation type="vanished">%1M</translation>
    </message>
    <message>
        <source>%1K</source>
        <translation type="vanished">%1K</translation>
    </message>
    <message>
        <source>%1</source>
        <translation type="vanished">%1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfoDialog</name>
    <message>
        <source>Film info</source>
        <translation>Informație video</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Rezoluție</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Durată</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tip</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Dimensiune</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Cale fișier</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation>Informații despre codificator</translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation>ID codificator video</translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation>Rata codificatorului video</translation>
    </message>
    <message>
        <source>%1 kbps</source>
        <translation>%1 kbps</translation>
    </message>
    <message>
        <source>FPS</source>
        <translation>FPS</translation>
    </message>
    <message>
        <source>%1 fps</source>
        <translation>%1 fps</translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation>Proportie</translation>
    </message>
    <message>
        <source>%1</source>
        <translation type="unfinished">%1</translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation>Informație audio</translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation>ID Codec audio</translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation>Rata codificării audio</translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation>Cifra audio</translation>
    </message>
    <message>
        <source>%1 bits</source>
        <translation>%1 biți</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>Canale</translation>
    </message>
    <message>
        <source>%1 channels</source>
        <translation>%1 canale</translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation>Eșantionare</translation>
    </message>
    <message>
        <source>%1hz</source>
        <translation>%1 Hz</translation>
    </message>
    <message>
        <source>%1 bps</source>
        <translation>%1 bps</translation>
    </message>
</context>
<context>
    <name>dmr::MpvProxy</name>
    <message>
        <source>Internal</source>
        <translation>Internal</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_MainWindow</name>
    <message>
        <source>Load successfully</source>
        <translation type="unfinished">Încărcare efectuată cu succes</translation>
    </message>
    <message>
        <source>Load failed</source>
        <translation type="unfinished">Încărcare eșuată</translation>
    </message>
    <message>
        <source>Cannot play the disc</source>
        <translation>Nu se poate juca discul</translation>
    </message>
    <message>
        <source>Parse failed</source>
        <translation>Analiza a eșuat</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="unfinished">Deschide dosar</translation>
    </message>
    <message>
        <source>All (*)</source>
        <translation>Toate (*)</translation>
    </message>
    <message>
        <source>Speed: %1x</source>
        <translation type="unfinished">Viteză: %1x</translation>
    </message>
    <message>
        <source>Stereo</source>
        <translation type="unfinished">Stereo</translation>
    </message>
    <message>
        <source>Left channel</source>
        <translation type="unfinished">Canal audio stanga</translation>
    </message>
    <message>
        <source>Right channel</source>
        <translation type="unfinished">Canal audio dreapta</translation>
    </message>
    <message>
        <source>Track: %1</source>
        <translation>Track: %1</translation>
    </message>
    <message>
        <source>Unable to adjust the subtitle</source>
        <translation>Nu se poate ajusta subtitlul</translation>
    </message>
    <message>
        <source>Subtitle %1: %2s</source>
        <translation type="unfinished">Subtitrare %1 %2s</translation>
    </message>
    <message>
        <source>delayed</source>
        <translation type="unfinished">întârziere</translation>
    </message>
    <message>
        <source>advanced</source>
        <translation type="unfinished">avansare</translation>
    </message>
    <message>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <comment>All (*)</comment>
        <translation type="unfinished">Subtitrare (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <source>View</source>
        <translation type="unfinished">Aspect</translation>
    </message>
    <message>
        <source>Film screenshot</source>
        <translation type="unfinished">Captură ecran video</translation>
    </message>
    <message>
        <source>Saved to</source>
        <translation type="unfinished">Salvare la</translation>
    </message>
    <message>
        <source>The screenshot is saved</source>
        <translation type="unfinished">Salvare captura de ecran efectuată</translation>
    </message>
    <message>
        <source>Failed to save the screenshot</source>
        <translation type="unfinished">Eșuat salvare captură de ecran</translation>
    </message>
    <message>
        <source>Taking the screenshots, please wait...</source>
        <translation>Se iau screenshot-urile, vă rugăm așteptați...</translation>
    </message>
    <message>
        <source>Reading DVD files...</source>
        <translation>Se citesc fișierele DVD...</translation>
    </message>
    <message>
        <source>No matching online subtitles</source>
        <translation>Nu există subtitluri online corespunzătoare</translation>
    </message>
    <message>
        <source>4K video may be stuck</source>
        <translation>Video-ul 4K poate fi blocat</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">Ok</translation>
    </message>
    <message>
        <source>Order play</source>
        <translation>Jocă în ordine</translation>
    </message>
    <message>
        <source>Shuffle play</source>
        <translation>Jocă în mod aleator</translation>
    </message>
    <message>
        <source>Single play</source>
        <translation>Jocă în mod unic</translation>
    </message>
    <message>
        <source>Single loop</source>
        <translation>Bucătă unică</translation>
    </message>
    <message>
        <source>List loop</source>
        <translation>Listă de bucle</translation>
    </message>
    <message>
        <source>Buffering...</source>
        <translation type="unfinished">Buferizare...</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation type="unfinished">Mute</translation>
    </message>
    <message>
        <source>Volume: %1%</source>
        <translation type="unfinished">Volum: %1%</translation>
    </message>
    <message>
        <source>Cannot open file or stream</source>
        <translation>Nu se poate deschide fișierul sau fluxul</translation>
    </message>
    <message>
        <source>Invalid file</source>
        <translation type="unfinished">Fișier nevalabil</translation>
    </message>
    <message>
        <source>Please insert a CD/DVD</source>
        <translation>Vă rugăm să introduceți un CD/DVD</translation>
    </message>
    <message>
        <source>No video file found</source>
        <translation>Nu s-a găsit fișier video</translation>
    </message>
    <message>
        <source>Please load the video first</source>
        <translation>Vă rugăm să încărcați mai întâi videoclipul</translation>
    </message>
    <message>
        <source>Please exit smart dock</source>
        <translation>Vă rugăm să ieșiți din smart dock</translation>
    </message>
    <message>
        <source>The CD/DVD has been ejected</source>
        <translation>CD-ul/DVD-ul a fost ejectat</translation>
    </message>
    <message>
        <source>The action is not supported in this video</source>
        <translation>Această acțiune nu este susținută în acest videoclip</translation>
    </message>
    <message>
        <source>Invalid file: %1</source>
        <translation type="unfinished">Fișier invalid: %1</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Conexiunea a eșuat</translation>
    </message>
    <message>
        <source>Miracast disconnected</source>
        <translation>Miracast a fost dezconectat</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Anulare</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>Redemarcați</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_PlayItemWidget</name>
    <message>
        <source>The file does not exist</source>
        <translation>Fișierul nu există</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_PlaylistWidget</name>
    <message>
        <source>Playlist</source>
        <translation type="unfinished">Lista de redare</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation type="unfinished">Gol</translation>
    </message>
    <message>
        <source>%1 videos</source>
        <translation>&apos;%1 videoclipuri&apos;</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_ToolboxProxy</name>
    <message>
        <source>Play/Pause</source>
        <translation type="unfinished">Redare/Pauză</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="unfinished">Precedent</translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="unfinished">Următorul</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished">Redare ecran complet</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation type="unfinished">Lista de redare</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation type="unfinished">Ieșire redare ecran complet</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished">Pauză</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished">Redare</translation>
    </message>
    <message>
        <source>Miracast</source>
        <translation>Miracast</translation>
    </message>
</context>
<context>
    <name>dmr::PlayItemWidget</name>
    <message>
        <source>The file does not exist</source>
        <translation>Fișierul nu există</translation>
    </message>
</context>
<context>
    <name>dmr::PlaylistWidget</name>
    <message>
        <source>Playlist</source>
        <translation>Lista de redare</translation>
    </message>
    <message>
        <source>%1 videos</source>
        <translation>&apos;%1 videoclipuri&apos;</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Gol</translation>
    </message>
</context>
<context>
    <name>dmr::Settings</name>
    <message>
        <source>%1/Movie%2(%3).jpg</source>
        <translation>&apos;%1/Movie%2(%3).jpg&apos;</translation>
    </message>
    <message>
        <source>Order play</source>
        <translation>Reproducere ordonată</translation>
    </message>
    <message>
        <source>Shuffle play</source>
        <translation>Reproducere aleatorie</translation>
    </message>
    <message>
        <source>Single play</source>
        <translation>Reproducere unică</translation>
    </message>
    <message>
        <source>Single loop</source>
        <translation>Repetare unică</translation>
    </message>
    <message>
        <source>List loop</source>
        <translation>Repetare listă</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automat</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Deschide</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Închide</translation>
    </message>
</context>
<context>
    <name>dmr::ToolboxProxy</name>
    <message>
        <source>Play</source>
        <translation>Redare</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Precedent</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Următorul</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation>Lista de redare</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Redare ecran complet</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Redare/Pauză</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Ieșire redare ecran complet</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauză</translation>
    </message>
    <message>
        <source>Miracast</source>
        <translation>Miracast</translation>
    </message>
    <message>
        <source>Volume</source>
        <translation>Volum</translation>
    </message>
</context>
<context>
    <name>dmr::VolumeButton</name>
    <message>
        <source>Volume</source>
        <translation>Volum</translation>
    </message>
</context>
</TS>
